@@ -11,7 +11,7 @@ EC_API_EXTERN void capture_stop(struct iface_env *);
 
 EC_API_EXTERN EC_THREAD_FUNC(capture);
 
-EC_API_EXTERN int is_pcap_file(char *file, char *errbuf);
+EC_API_EXTERN int is_pcap_file(char *file, char *pcap_errbuf);
 EC_API_EXTERN void capture_getifs(void);
 
 #define FUNC_ALIGNER(func) int func(void)
