@@ -1,5 +1,4 @@
 
-/* $Id: ec_filter.h,v 1.22 2005/01/04 14:30:49 alor Exp $ */
 
 #ifndef EC_FILTER_H
 #define EC_FILTER_H
@@ -113,6 +112,14 @@ struct filter_env {
    size_t len;
 };
 
+/* filter list entry */
+struct filter_list {
+	uint8_t enabled;
+	char *name;
+	struct filter_env env;
+	struct filter_list *next;
+};
+
 /* uset to compile the regex while loading the file */
 struct regex_opt {
    regex_t *regex;
@@ -124,11 +131,15 @@ struct regex_opt {
 
 #define PCRE_OVEC_SIZE 100
 
+void filter_init_mutex(void);
+
 /* exported functions */
 
-EC_API_EXTERN int filter_engine(struct filter_op *fop, struct packet_object *po);
-EC_API_EXTERN int filter_load_file(char *filename, struct filter_env *fenv);
-EC_API_EXTERN void filter_unload(struct filter_env *fenv);
+EC_API_EXTERN void filter_packet(struct packet_object *po);
+EC_API_EXTERN int filter_load_file(char *filename, struct filter_list **list, uint8_t enabled);
+EC_API_EXTERN void filter_unload(struct filter_list **list);
+EC_API_EXTERN void filter_clear(void);
+EC_API_EXTERN void filter_walk_list( int(*cb)(struct filter_list*, void*), void *arg);
 
 #endif
 
