@@ -8,7 +8,7 @@
 #include <ec_fingerprint.h>
 #include <ec_inet.h>
 #include <ec_session.h>
-
+#include <pcap.h>
 #include <sys/time.h>
 
 struct packet_object {
@@ -19,16 +19,18 @@ struct packet_object {
    struct L2 {
       u_int8 proto;
       u_char * header;
-      size_t len;
+      bpf_u_int32 len;
       u_int8 src[MEDIA_ADDR_LEN];
       u_int8 dst[MEDIA_ADDR_LEN];
+      u_int8 flags;
+         #define PO_L2_FCS  0x01
    } L2;
    
    struct L3 {
       u_int16 proto;
       u_char * header;
       u_char * options;
-      size_t len;
+      bpf_u_int32 len;
       size_t payload_len;
       size_t optlen;
       struct ip_addr src;
@@ -41,7 +43,7 @@ struct packet_object {
       u_int8 flags;
       u_char * header;
       u_char * options;
-      size_t len;
+      bpf_u_int32 len;
       size_t optlen;
       u_int16 src;
       u_int16 dst;
@@ -51,7 +53,7 @@ struct packet_object {
    
    struct data {
       u_char * data;
-      size_t len;
+      bpf_u_int32 len;
       /* 
        * buffer containing the data to be displayed.
        * some dissector decripts the traffic, but the packet must be forwarded as
@@ -67,10 +69,10 @@ struct packet_object {
 
    } DATA;
 
-   size_t fwd_len;         /* length of the packet to be forwarded */
+   bpf_u_int32 fwd_len;    /* length of the packet to be forwarded */
    u_char * fwd_packet;    /* the pointer to the buffer to be forwarded */
    
-   size_t len;             /* total length of the packet */
+   bpf_u_int32 len;        /* total length of the packet */
    u_char * packet;        /* the buffer containing the real packet */
 
    /* Trace current session for injector chain */
@@ -109,10 +111,10 @@ struct packet_object {
    
 };
 
-EC_API_EXTERN struct packet_object* packet_allocate_object(u_char *data, size_t len);
-EC_API_EXTERN inline int packet_create_object(struct packet_object *po, u_char * buf, size_t len);
+EC_API_EXTERN struct packet_object* packet_allocate_object(u_char *data, bpf_u_int32 len);
+EC_API_EXTERN inline int packet_create_object(struct packet_object *po, u_char * buf, bpf_u_int32 len);
 EC_API_EXTERN inline int packet_destroy_object(struct packet_object *po);
-EC_API_EXTERN int packet_disp_data(struct packet_object *po, u_char *buf, size_t len);
+EC_API_EXTERN int packet_disp_data(struct packet_object *po, u_char *buf, bpf_u_int32 len);
 EC_API_EXTERN struct packet_object * packet_dup(struct packet_object *po, u_char flag);
 
 /* Do we want to duplicate data? */
