@@ -1,5 +1,4 @@
 
-/* $Id: ec_stdint.h,v 1.7 2004/07/05 19:26:17 alor Exp $ */
 
 #ifndef EC_STDINT_H
 #define EC_STDINT_H
@@ -21,12 +20,12 @@
 	typedef int32_t   int32;
 	typedef int64_t   int64;
 
-	typedef uint8_t   u_int8;
-	typedef uint16_t  u_int16;
-	typedef uint32_t  u_int32;
-	typedef uint64_t  u_int64;
+	typedef u_int8_t   u_int8;
+	typedef u_int16_t  u_int16;
+	typedef u_int32_t  u_int32;
+	typedef u_int64_t  u_int64;
 
-   #ifdef OS_BSD_OPEN
+   #if defined OS_BSD_OPEN && !defined HAVE_STDINT_H
       #define INT8_MAX     CHAR_MAX
       #define UINT8_MAX    UCHAR_MAX
       #define INT16_MAX    SHRT_MAX
