@@ -159,7 +159,7 @@ static void parse_arp(struct packet_object *po)
 {
    struct ip_addr sa;
    
-   ip_addr_init(&sa, AF_INET, (char *)&(fake_ip.s_addr));
+   ip_addr_init(&sa, AF_INET, (u_char *)&(fake_ip.s_addr));
    if (!ip_addr_cmp(&sa, &po->L3.dst))
       send_arp(ARPOP_REPLY, &sa, GBL_IFACE->mac, &po->L3.src, po->L2.src);
 }
