@@ -60,11 +60,11 @@ FUNC_DECODER(dissector_ftp)
        * get the banner 
        * ptr + 4 to skip the initial 220 response
        */
-      if (!strncmp(ptr, "220", 3)) {
-         PACKET->DISSECTOR.banner = strdup(ptr + 4);
+      if (!strncmp((const char*)ptr, "220", 3)) {
+         PACKET->DISSECTOR.banner = strdup((const char*)ptr + 4);
          
          /* remove the \r\n */
-         if ( (ptr = strchr(PACKET->DISSECTOR.banner, '\r')) != NULL )
+         if ( (ptr = (u_char*)strchr(PACKET->DISSECTOR.banner, '\r')) != NULL )
             *ptr = '\0';
       }
      
@@ -88,7 +88,7 @@ FUNC_DECODER(dissector_ftp)
       return NULL;
    
    /* harvest the username */
-   if ( !strncasecmp(ptr, "USER ", 5) ) {
+   if ( !strncasecmp((const char*)ptr, "USER ", 5) ) {
 
       DEBUG_MSG("\tDissector_FTP USER");
       
@@ -101,10 +101,10 @@ FUNC_DECODER(dissector_ftp)
       SAFE_FREE(s->data);
 
       /* fill the session data */
-      s->data = strdup(ptr);
-      s->data_len = strlen(ptr);
+      s->data = strdup((const char*)ptr);
+      s->data_len = strlen((const char*)ptr);
       
-      if ( (ptr = strchr(s->data,'\r')) != NULL )
+      if ( (ptr = (u_char*)strchr(s->data,'\r')) != NULL )
          *ptr = '\0';
       
       /* save the session */
@@ -114,7 +114,7 @@ FUNC_DECODER(dissector_ftp)
    }
 
    /* harvest the password */
-   if ( !strncasecmp(ptr, "PASS ", 5) ) {
+   if ( !strncasecmp((const char*)ptr, "PASS ", 5) ) {
 
       DEBUG_MSG("\tDissector_FTP PASS");
       
@@ -138,8 +138,8 @@ FUNC_DECODER(dissector_ftp)
       /* fill the structure */
       PACKET->DISSECTOR.user = strdup(s->data);
       
-      PACKET->DISSECTOR.pass = strdup(ptr);
-      if ( (ptr = strchr(PACKET->DISSECTOR.pass, '\r')) != NULL )
+      PACKET->DISSECTOR.pass = strdup((const char*)ptr);
+      if ( (ptr = (u_char*)strchr(PACKET->DISSECTOR.pass, '\r')) != NULL )
          *ptr = '\0';
 
       /* free the session */
