@@ -411,6 +411,10 @@ static int Parse_User_Agent(char* ptr, char* end, char *from_here, struct packet
                 // skip the ; and the ' '
                 comment_begin += 2;
             }
+            else
+            {
+            	comment_begin = NULL;
+            }
         } else {
             const char* the_end = memchr(comment_begin, ';', comment_end - comment_begin);
             if (the_end != NULL) {
@@ -525,6 +529,7 @@ static int Parse_NTLM_Auth(char *ptr, char *from_here, struct packet_object *po)
 static void Parse_Post_Payload(char *ptr, struct http_status *conn_status, struct packet_object *po)
 { 
    char *user=NULL, *pass=NULL;
+   u_char user_res, pass_res;
 
    DEBUG_MSG("HTTP - Parse First chance");
    
@@ -537,14 +542,19 @@ static void Parse_Post_Payload(char *ptr, struct http_status *conn_status, struc
    if (conn_status->c_status == POST_LAST_CHANCE) {
    DEBUG_MSG("HTTP - Parse Form");
 
-      if (Parse_Form(ptr, &user, USER) && Parse_Form(ptr, &pass, PASS)) {
+      user_res= Parse_Form(ptr, &user, USER);
+      pass_res= Parse_Form(ptr, &pass, PASS);
+      if (user_res || pass_res) {
          po->DISSECTOR.user = user;
          po->DISSECTOR.pass = pass;
+         po->DISSECTOR.content = strdup((const char*) ptr);
          po->DISSECTOR.info = strdup((const char*)conn_status->c_data);
          dissect_wipe_session(po, DISSECT_CODE(dissector_http));
          Print_Pass(po);
-      } else
+      } else {
          SAFE_FREE(user);
+         SAFE_FREE(pass);
+      }
    }
 }
 
@@ -773,6 +783,9 @@ static void Print_Pass(struct packet_object *po)
                                                                  po->DISSECTOR.user,
                                                                  po->DISSECTOR.pass,
                                                                  po->DISSECTOR.info);
+
+   if (po->DISSECTOR.content)
+    DISSECT_MSG("CONTENT: %s\n\n", po->DISSECTOR.content);
 }
 
 
@@ -788,7 +801,7 @@ int http_fields_init(void)
    /* open the file */
    f = open_data("share", ETTER_FIELDS, FOPEN_READ_TEXT);
    if (f == NULL) {
-      USER_MSG("Cannot open %s", ETTER_FIELDS);
+      USER_MSG("Cannot open %s\n", ETTER_FIELDS);
       return -EINVALID;
    }
          
@@ -851,7 +864,7 @@ static char *unicodeToString(char *p, size_t len)
    u_int32 i;
    static char buf[1024];
 
-   /* A string longer than 1024 chars???...it's a bougs packet */
+   /* A string longer than 1024 chars???...it's a bogus packet */
    for (i=0; i<len && i<1023; ++i) {
       buf[i] = *p & 0x7f;
       p += 2;
