@@ -70,7 +70,7 @@ FUNC_DECODER(dissector_msn)
       if (session_get(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) {
       
          /* search the login */
-         ptr = strstr(ptr, "MD5 I ");
+         ptr = (u_char*)strstr((const char*)ptr, "MD5 I ");
          
          /* not found */
          if (ptr == NULL)
@@ -82,10 +82,10 @@ FUNC_DECODER(dissector_msn)
          dissect_create_session(&s, PACKET, DISSECT_CODE(dissector_msn));
 	 
          /* save the login */
-         s->data = strdup(ptr + strlen("MD5 I "));
+         s->data = strdup((const char*)ptr + strlen("MD5 I "));
 	    
          /* tuncate at the \r */
-         if ( (ptr = strchr(s->data,'\r')) != NULL )
+         if ( (ptr = (u_char*)strchr(s->data,'\r')) != NULL )
             *ptr = '\0';
 
          session_put(s);
@@ -98,7 +98,7 @@ FUNC_DECODER(dissector_msn)
          if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
          
             /* search the login */
-            ptr = strstr(ptr, "MD5 S ");
+            ptr = (u_char*)strstr((const char*)ptr, "MD5 S ");
             
             /* not found */
             if (ptr == NULL)
@@ -107,11 +107,11 @@ FUNC_DECODER(dissector_msn)
             DEBUG_MSG("\tDissector_msn - PASS ");
             
             /* save the challenge after the login */
-            SAFE_REALLOC(s->data, strlen(s->data) + strlen(ptr) + 2);
-            snprintf(s->data + strlen(s->data), strlen(s->data) + strlen(ptr)+2, " %s", ptr + strlen("MD5 S "));
+            SAFE_REALLOC(s->data, strlen(s->data) + strlen((const char*)ptr) + 2);
+            snprintf(s->data + strlen(s->data), strlen(s->data) + strlen((const char*)ptr)+2, " %s", ptr + strlen("MD5 S "));
             
             /* tuncate at the \r */
-            if ( (ptr = strchr(s->data,'\r')) != NULL )
+            if ( (ptr = (u_char*)strchr(s->data,'\r')) != NULL )
                *ptr = '\0';
             
             /* save the proper value (splitting the string)
@@ -149,7 +149,7 @@ FUNC_DECODER(dissector_msn)
       if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
       
          /* search the login */
-         ptr = strstr(ptr, "MD5 S ");
+         ptr = (u_char*)strstr((const char*)ptr, "MD5 S ");
          
          /* not found */
          if (ptr == NULL)
@@ -158,11 +158,11 @@ FUNC_DECODER(dissector_msn)
          DEBUG_MSG("\tDissector_msn - CHALLENGE ");
          
          /* save the challenge after the login */
-         SAFE_REALLOC(s->data, strlen(s->data) + strlen(ptr) + 2);
-         snprintf(s->data + strlen(s->data), strlen(s->data)+strlen(ptr)+2, " %s", ptr + strlen("MD5 S "));
+         SAFE_REALLOC(s->data, strlen(s->data) + strlen((const char*)ptr) + 2);
+         snprintf(s->data + strlen(s->data), strlen(s->data)+strlen((const char*)ptr)+2, " %s", ptr + strlen("MD5 S "));
          
          /* tuncate at the \r */
-         if ( (ptr = strchr(s->data,'\r')) != NULL )
+         if ( (ptr = (u_char*)strchr(s->data,'\r')) != NULL )
             *ptr = '\0';
          
       }
