@@ -63,11 +63,11 @@ FUNC_DECODER(dissector_smtp)
        * get the banner 
        * ptr + 4 to skip the initial 220 response
        */
-      if (!strncmp(ptr, "220", 3)) {
-         PACKET->DISSECTOR.banner = strdup(ptr + 4);
+      if (!strncmp((const char*)ptr, "220", 3)) {
+         PACKET->DISSECTOR.banner = strdup((const char*)ptr + 4);
          
          /* remove the \r\n */
-         if ( (ptr = strchr(PACKET->DISSECTOR.banner, '\r')) != NULL )
+         if ( (ptr = (u_char*)strchr(PACKET->DISSECTOR.banner, '\r')) != NULL )
             *ptr = '\0';
       }
             
@@ -99,7 +99,7 @@ FUNC_DECODER(dissector_smtp)
  *
  * the digests are in base64
  */
-   if ( !strncasecmp(ptr, "AUTH LOGIN", 10) ) {
+   if ( !strncasecmp((const char*)ptr, "AUTH LOGIN", 10) ) {
       
       DEBUG_MSG("\tDissector_smtp AUTH LOGIN");
 
@@ -134,16 +134,16 @@ FUNC_DECODER(dissector_smtp)
       return NULL;
    }
    
-   if (!strcmp(s->data, "AUTH")) {
+   if (!strcmp((const char*)s->data, "AUTH")) {
       char *user;
       int i;
      
       DEBUG_MSG("\tDissector_smtp AUTH LOGIN USER");
       
-      SAFE_CALLOC(user, strlen(ptr), sizeof(char));
+      SAFE_CALLOC(user, strlen((const char*)ptr), sizeof(char));
      
       /* username is encoded in base64 */
-      i = base64_decode(user, ptr);
+      i = base64_decode(user, (const char*)ptr);
      
       SAFE_FREE(s->data);
 
@@ -163,10 +163,10 @@ FUNC_DECODER(dissector_smtp)
      
       DEBUG_MSG("\tDissector_smtp AUTH LOGIN PASS");
       
-      SAFE_CALLOC(pass, strlen(ptr), sizeof(char));
+      SAFE_CALLOC(pass, strlen((const char*)ptr), sizeof(char));
       
       /* password is encoded in base64 */
-      base64_decode(pass, ptr);
+      base64_decode(pass, (const char*)ptr);
      
       /* fill the structure */
       PACKET->DISSECTOR.user = strdup(s->data + strlen("AUTH USER "));
