@@ -168,10 +168,10 @@ FUNC_DECODER(dissector_ssh)
          }
 
          /* Catch the version banner */
-         PACKET->DISSECTOR.banner = strdup(PACKET->DATA.data);
+         PACKET->DISSECTOR.banner = strdup((const char*)PACKET->DATA.data);
          
          /* remove the \n */
-         if ( (ptr = strchr(PACKET->DISSECTOR.banner, '\n')) != NULL )
+         if ( (ptr = (u_char*)strchr(PACKET->DISSECTOR.banner, '\n')) != NULL )
             *ptr = '\0';
       }      
    } else { /* The session exists */
@@ -248,7 +248,7 @@ FUNC_DECODER(dissector_ssh)
                } else
                   PACKET->DISSECTOR.pass = strdup("(empty)");
 		  
-               PACKET->DISSECTOR.user = strdup(session_data->user); /* Surely NULL terminated */
+               PACKET->DISSECTOR.user = strdup((const char*)session_data->user); /* Surely NULL terminated */
                DISSECT_MSG("SSH : %s:%d -> USER: %s  PASS: %s\n", ip_addr_ntoa(&PACKET->L3.dst, tmp),
                                                                ntohs(PACKET->L4.dst),
                                                                PACKET->DISSECTOR.user,
@@ -256,7 +256,7 @@ FUNC_DECODER(dissector_ssh)
 
             } else if (ssh_packet_type == CMSG_AUTH_RHOSTS) {
                DEBUG_MSG("\tDissector_ssh RHOSTS");
-               PACKET->DISSECTOR.user = strdup(session_data->user);
+               PACKET->DISSECTOR.user = strdup((const char*)session_data->user);
                /* XXX Do we need to catch more infos from this kind of packet? */
                PACKET->DISSECTOR.pass = strdup("RHOSTS-AUTH\n");
                DISSECT_MSG("SSH : %s:%d -> USER: %s  %s\n", ip_addr_ntoa(&PACKET->L3.dst, tmp),
@@ -265,7 +265,7 @@ FUNC_DECODER(dissector_ssh)
                                                          PACKET->DISSECTOR.pass);
             } else if (ssh_packet_type == CMSG_AUTH_RSA) {
                DEBUG_MSG("\tDissector_ssh RSA AUTH");
-               PACKET->DISSECTOR.user = strdup(session_data->user);
+               PACKET->DISSECTOR.user = strdup((const char*)session_data->user);
                PACKET->DISSECTOR.pass = strdup("RSA-AUTH\n");
                DISSECT_MSG("SSH : %s:%d -> USER: %s  %s\n", ip_addr_ntoa(&PACKET->L3.dst, tmp),
                                                          ntohs(PACKET->L4.dst),
