@@ -80,7 +80,7 @@ FUNC_DECODER(dissector_x11)
        * it should be better checked in the header to find the 
        * banner length etc etc...
        */
-      PACKET->DISSECTOR.banner = strdup(PACKET->DATA.disp_data + 40);
+      PACKET->DISSECTOR.banner = strdup((const char*)PACKET->DATA.disp_data + 40);
      
    } ENDIF_FIRST_PACKET_FROM_SERVER(s, ident)
    
@@ -108,7 +108,7 @@ FUNC_DECODER(dissector_x11)
       return NULL;
    
    /* check the magic string */
-   if (strncmp(x11->name, "MIT-MAGIC-COOKIE-1", x11->name_len))
+   if (strncmp((const char*)x11->name, "MIT-MAGIC-COOKIE-1", x11->name_len))
       return NULL;
        
    DEBUG_MSG("\tDissector_x11 COOKIE");
