@@ -40,13 +40,15 @@
 #include <ec_conf.h>
 #include <ec_mitm.h>
 #include <ec_sslwrap.h>
+#ifdef HAVE_EC_LUA
+#include <ec_lua.h>
+#endif
 
 /* global vars */
 
 
 /* protos */
 
-void clean_exit(int errcode);
 static void drop_privs(void);
 static void time_check(void);
 
@@ -149,6 +151,11 @@ int main(int argc, char *argv[])
    /* load http known fileds for user/pass */
    http_fields_init();
 
+#ifdef HAVE_EC_LUA
+   /* Initialize lua */
+   ec_lua_init();
+#endif
+
    /* set the encoding for the UTF-8 visualization */
    set_utf8_encoding((u_char*)GBL_CONF->utf8_encoding);
   
@@ -236,37 +243,6 @@ static void drop_privs(void)
 }
 
 
-/*
- * cleanly exit from the program
- */
-
-void clean_exit(int errcode)
-{
-   DEBUG_MSG("clean_exit: %d", errcode);
-  
-   INSTANT_USER_MSG("\nTerminating %s...\n", GBL_PROGRAM);
-
-   /* flush the exit message */
-   ui_msg_flush(MSG_ALL);
-
-   /* stop the mitm attack */
-   mitm_stop();
-
-   /* terminate the sniffing engine */
-   EXECUTE(GBL_SNIFF->cleanup);
-
-   /* kill all the running threads but the current */
-   ec_thread_kill_all();
-
-   /* close the UI */
-   ui_cleanup();
-
-   /* call all the ATEXIT functions */
-   exit(errcode);
-
-}
-
-
 static void time_check(void)
 {
    /* 
