@@ -47,6 +47,7 @@ static int profile_add_host(struct packet_object *po);
 static int profile_add_user(struct packet_object *po);
 static void update_info(struct host_profile *h, struct packet_object *po);
 static void update_port_list(struct host_profile *h, struct packet_object *po);
+static void update_port_list_with_advertised(struct host_profile *h, uint8_t L4_proto, uint16_t L4_src);
 static void set_gateway(u_char *L2_addr);
 
 void * profile_print(int mode, void *list, char **desc, size_t len);
@@ -132,7 +133,8 @@ void profile_parse(struct packet_object *po)
     */
    if ( is_open_port(po->L4.proto, po->L4.src, po->L4.flags) ||   /* src port is open */
         strcmp(po->PASSIVE.fingerprint, "") ||                    /* collected fingerprint */  
-        po->DISSECTOR.banner                                      /* banner */
+        po->DISSECTOR.banner ||                                     /* banner */
+        po->DISSECTOR.os
       )
       profile_add_host(po);
 
@@ -144,10 +146,15 @@ void profile_parse(struct packet_object *po)
     */
    if ( po->DISSECTOR.user ||                               /* user */
         po->DISSECTOR.pass ||                               /* pass */
-        po->DISSECTOR.info                                  /* info */
+        po->DISSECTOR.info                                 /* info */
       )
       profile_add_user(po);
-   
+
+   if ( po->DISSECTOR.advertised_port != 0 &&
+        po->DISSECTOR.advertised_proto != 0
+      )
+      profile_add_host(po);
+
    return;
 }
 
@@ -276,7 +283,10 @@ static void update_info(struct host_profile *h, struct packet_object *po)
       
    /* get the hostname */
    host_iptoa(&po->L3.src, h->hostname);
-   
+
+   if (po->DISSECTOR.os && h->os == NULL)
+      h->os = strdup(po->DISSECTOR.os);
+
    /* 
     * update the fingerprint only if there isn't a previous one
     * or if the previous fingerprint was an ACK
@@ -289,6 +299,9 @@ static void update_info(struct host_profile *h, struct packet_object *po)
 
    /* add the open port */
    update_port_list(h, po);
+
+   if (po->DISSECTOR.advertised_proto != 0 && po->DISSECTOR.advertised_port != 0)
+      update_port_list_with_advertised(h, po->DISSECTOR.advertised_proto, po->DISSECTOR.advertised_port);
 }
 
 
@@ -370,6 +383,43 @@ static void update_port_list(struct host_profile *h, struct packet_object *po)
    
 }
 
+static void update_port_list_with_advertised(struct host_profile *h, uint8_t L4_proto, uint16_t L4_src)
+{
+   struct open_port *o;
+   struct open_port *p;
+   struct open_port *last = NULL;
+
+   /* search for an existing port */
+   LIST_FOREACH(o, &(h->open_ports_head), next) {
+      if (o->L4_proto == L4_proto && o->L4_addr == L4_src) {
+          // already logged
+         return;
+      }
+   }
+
+   DEBUG_MSG("update_port_list_with_advertised");
+
+   /* create a new entry */
+   SAFE_CALLOC(o, 1, sizeof(struct open_port));
+
+   o->L4_proto = L4_proto;
+   o->L4_addr = L4_src;
+
+   /* search the right point to inser it (ordered ascending) */
+   LIST_FOREACH(p, &(h->open_ports_head), next) {
+      if ( ntohs(p->L4_addr) > ntohs(o->L4_addr) )
+         break;
+      last = p;
+   }
+
+   /* insert in the right position */
+   if (LIST_FIRST(&(h->open_ports_head)) == NULL)
+      LIST_INSERT_HEAD(&(h->open_ports_head), o, next);
+   else if (p != NULL)
+      LIST_INSERT_BEFORE(p, o, next);
+   else
+      LIST_INSERT_AFTER(last, o, next);
+}
 /* 
  * update the users list
  */
@@ -507,7 +557,7 @@ static void profile_purge(int flags)
    struct host_profile *h, *tmp_h = NULL;
    struct open_port *o, *tmp_o = NULL;
    struct active_user *u, *tmp_u = NULL;
-   
+
    PROFILE_LOCK;
 
    TAILQ_FOREACH_SAFE(h, &GBL_PROFILES, next, tmp_h) {
@@ -531,6 +581,7 @@ static void profile_purge(int flags)
             LIST_REMOVE(o, next);
             SAFE_FREE(o);
          }
+         SAFE_FREE(h->os);
          TAILQ_REMOVE(&GBL_PROFILES, h, next);
          SAFE_FREE(h);
       }
