@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: wdg.c,v 1.36 2004/03/18 14:22:19 alor Exp $
 */
 
 #include <wdg.h>
@@ -27,7 +26,7 @@
 
 /* GLOBALS */
 
-/* informations about the current screen */
+/* information about the current screen */
 struct wdg_scr current_screen;
 
 /* called when idle */
