@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_gtk_conf.c,v 1.2 2004/09/30 02:09:27 daten Exp $
 */
 
 #include <ec.h>
@@ -65,19 +64,13 @@ short gtkui_conf_get(char *name) {
 
 void gtkui_conf_read(void) {
    FILE *fd;
-   char *path;
-   char line[50], name[30];
+   const char *path;
+   char line[100], name[30];
    short value;
 
-#ifdef OS_WINDOWS
-   path = ec_win_get_user_dir();
-#else
-   /* TODO: get the dopped privs home dir instead of "/root" */
-   /* path = g_get_home_dir(); */
-   path = g_get_tmp_dir();
-#endif
-
-   filename = g_build_filename(path, ".ettercap_gtk", NULL);
+   /* If you launch ettercap using sudo, then the config file is your user config dir */
+   path = g_get_user_config_dir();
+   filename = g_build_filename(path, "ettercap_gtk", NULL);
 
    DEBUG_MSG("gtkui_conf_read: %s", filename);
 
@@ -86,8 +79,14 @@ void gtkui_conf_read(void) {
       return;
 
    while(fgets(line, 100, fd)) {
-      sscanf(line, "%s = %hd", name, &value);
-
+      char *p = strchr(line, '=');
+     if(!p)
+         continue;
+      *p = '\0';
+      snprintf(name, sizeof(name), "%s", line);
+      strlcpy(name, line, sizeof(name) - 1);
+      g_strstrip(name);
+      value = atoi(p + 1);
       gtkui_conf_set(name, value);
    }
    fclose(fd);
