@@ -23,6 +23,7 @@
 #include <ec_gtk.h>
 #include <ec_format.h>
 #include <ec_parser.h>
+#include <ec_encryption.h>
 
 /* proto */
 
@@ -31,8 +32,8 @@ void toggle_resolve(void);
 void gtkui_vis_method(void);
 void gtkui_vis_regex(void);
 static void gtkui_set_regex(void);
-void gtkui_wep_key(void);
-static void gtkui_set_wepkey(void);
+void gtkui_wifi_key(void);
+static void gtkui_set_wifikey(void);
 
 static void gtkui_stop_stats(void);
 static void gtkui_stats_detach(GtkWidget *child);
@@ -42,9 +43,6 @@ static gboolean refresh_stats(gpointer data);
 extern void gtkui_show_profiles(void);
 extern void gtkui_show_connections(void);
 
-/* from the ec_wifi.c decoder */
-extern int set_wep_key(u_char *string);
-
 /* globals */
 
 #define VLEN 8
@@ -453,18 +451,18 @@ static void gtkui_set_regex(void)
 }
 
 /*
- * set the WEP key
+ * set the Wifi key
  */
-void gtkui_wep_key(void)
+void gtkui_wifi_key(void)
 {
-   DEBUG_MSG("gtk_wep_key");
+   DEBUG_MSG("gtk_wifi_key");
 
-   gtkui_input("WEP key :", wkey, WLEN, gtkui_set_wepkey);
+   gtkui_input("WiFi key :", wkey, WLEN, gtkui_set_wifikey);
 }
 
-static void gtkui_set_wepkey(void)
+static void gtkui_set_wifikey(void)
 {
-   set_wep_key(wkey);
+   wifi_key_prepare(wkey);
 }
 
 /* EOF */
