@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_gtk_view_connections.c,v 1.39 2004/07/12 19:57:43 alor Exp $
 */
 
 #include <ec.h>
@@ -28,9 +27,6 @@
 #include <ec_format.h>
 #include <ec_inject.h>
 
-#ifndef OS_WINDOWS
-   #include <sys/mman.h>
-#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -362,7 +358,8 @@ static gboolean refresh_connections(gpointer data)
       /* extract changing values from conntrack_print string */
       flags[0] = desc[0];
       strncpy(status, desc+50, 7);
-      sscanf(desc+62, "%u", &xferred);
+      int i =sscanf(desc+62, "%u", &xferred);
+      BUG_IF(i!=1);  
 
       gtk_list_store_set (ls_conns, &iter, 0, flags, 7, status, 8, xferred, -1);
 
@@ -370,7 +367,8 @@ static gboolean refresh_connections(gpointer data)
       if(bottom.conn == list)
          break;
    } while(gtk_tree_model_iter_next(model, &iter));
-   
+  
+   SAFE_FREE(desc); 
    return(TRUE);
 }
 
@@ -401,9 +399,13 @@ static struct row_pairs *gtkui_connections_add(char *desc, void *conn, struct ro
    strncpy(dst, desc+26, 15);
    strncpy(status, desc+50, 7);
 
-   sscanf(desc+18, "%u", &src_port);
-   sscanf(desc+42, "%u", &dst_port);
+   int i=0;
+   i=sscanf(desc+18, "%u", &src_port);
+   BUG_IF(i!=1);
+   i=sscanf(desc+42, "%u", &dst_port);
+   BUG_IF(i!=1);
    sscanf(desc+62, "%u", &xferred);
+   BUG_IF(i!=1);
 
    /* trim off leading spaces */
    for(src_ptr = src; *src_ptr == ' '; src_ptr++);
@@ -818,7 +820,6 @@ static void gtkui_data_print(int buffer, char *data, int color)
    GtkTextBuffer *textbuf = NULL;
    GtkWidget *textview = NULL;
    GtkTextMark *endmark = NULL;
-   const gchar *end;
    char *unicode = NULL;
 
    switch(buffer) {
@@ -843,16 +844,7 @@ static void gtkui_data_print(int buffer, char *data, int color)
 
    
    /* make sure data is valid UTF8 */
-   unicode = data;
-   if(!g_utf8_validate (data, -1, &end)) {
-      /* if "end" pointer is at begining of string, we have no valid text to print */
-      if(end == unicode) return;
-      /* cut off the invalid part so we don't lose the whole string */
-      /* this shouldn't happen often */
-      unicode = (char *)end;
-      *unicode = 0;
-      unicode = data;
-   }
+   unicode = gtkui_utf8_validate(data);
 
    /* if interface has been destroyed or unicode conversion failed */
    if(!data_window || !textbuf || !textview || !endmark || !unicode)
@@ -913,12 +905,10 @@ static void split_print_po(struct packet_object *po)
    ret = GBL_FORMAT(po->DATA.disp_data, po->DATA.disp_len, dispbuf);
    dispbuf[ret] = 0;
         
-   gdk_threads_enter();
    if (!ip_addr_cmp(&po->L3.src, &curr_conn->L3_addr1))
       gtkui_data_print(1, dispbuf, 0);
    else
       gtkui_data_print(2, dispbuf, 0);
-   gdk_threads_leave();
 }
 
 /*
@@ -1080,12 +1070,10 @@ static void join_print_po(struct packet_object *po)
    ret = GBL_FORMAT(po->DATA.disp_data, po->DATA.disp_len, dispbuf);
    dispbuf[ret] = 0;
         
-   gdk_threads_enter();
    if (!ip_addr_cmp(&po->L3.src, &curr_conn->L3_addr1))
       gtkui_data_print(3, dispbuf, 1);
    else
       gtkui_data_print(3, dispbuf, 2);
-   gdk_threads_leave();
 }
 
 /*
@@ -1235,7 +1223,7 @@ static void gtkui_connection_inject(void)
       /* advance end iter to end of text, 500 char max */
       gtk_text_iter_forward_chars(&end, 500);
       
-      strcpy(injectbuf, gtk_text_buffer_get_text(buf, &start, &end, FALSE));
+      strncpy(injectbuf, gtk_text_buffer_get_text(buf, &start, &end, FALSE), 501);
 
       if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (button1)))
          gtkui_inject_user(1);
@@ -1268,7 +1256,7 @@ static void gtkui_connection_inject_file(void)
    GtkWidget *dialog, *label, *vbox, *hbox;
    GtkWidget *button1, *button2, *button, *entry;
    char tmp[MAX_ASCII_ADDR_LEN];
-   char *filename = NULL;
+   const char *filename = NULL;
    gint response = 0;
    
    DEBUG_MSG("gtk_connection_inject_file");
@@ -1341,12 +1329,12 @@ static void gtkui_inject_file(char *filename, int side)
 {
    int fd;
    void *buf;
-   size_t size;
+   size_t size, ret;
    
    DEBUG_MSG("inject_file %s", filename);
    
    /* open the file */
-   if ((fd = open(filename, O_RDONLY)) == -1) {
+   if ((fd = open(filename, O_RDONLY | O_BINARY)) == -1) {
       ui_error("Can't load the file");
       return;
    }
@@ -1354,20 +1342,27 @@ static void gtkui_inject_file(char *filename, int side)
    /* calculate the size of the file */
    size = lseek(fd, 0, SEEK_END);
    
-   /* map it to the memory */
-   buf = mmap(NULL, size, PROT_READ, MAP_PRIVATE, fd, 0);
-   if (buf == MAP_FAILED) {
-      ui_error("Can't mmap the file");
+   /* load the file in memory */
+   SAFE_CALLOC(buf, size, sizeof(char));
+            
+   /* rewind the pointer */
+   lseek(fd, 0, SEEK_SET);
+               
+   ret = read(fd, buf, size);
+
+   close(fd);
+
+   if (ret != size) {
+      ui_error("Cannot read the file into memory");
       return;
    }
-
+      
    /* check where to inject */
    if (side == 1 || side == 2) {
       user_inject(buf, size, curr_conn, side);
    }
 
-   close(fd);
-   munmap(buf, size);
+   SAFE_FREE(buf);
 }
 
 /* EOF */
