@@ -84,6 +84,12 @@ static int dhcp_spoofing_start(char *args)
 
    if (!strcmp(args, ""))
       SEMIFATAL_ERROR("DHCP spoofing needs a parameter.\n");
+
+   /*
+    * Check to see if sniff has started
+    */
+   if (!GBL_SNIFF->active)
+      SEMIFATAL_ERROR("DHCP spoofing requires sniffing to be active.\n");
    
    /* check the parameter:
     *
