@@ -90,8 +90,8 @@ FUNC_DECODER(decode_arp)
       struct arp_eth_header *earp;
       earp = (struct arp_eth_header *)(arp + 1);
       
-      ip_addr_init(&PACKET->L3.src, AF_INET, (char *)&earp->arp_spa);
-      ip_addr_init(&PACKET->L3.dst, AF_INET, (char *)&earp->arp_tpa);
+      ip_addr_init(&PACKET->L3.src, AF_INET, (u_char *)&earp->arp_spa);
+      ip_addr_init(&PACKET->L3.dst, AF_INET, (u_char *)&earp->arp_tpa);
            
 
       /* 
