@@ -17,7 +17,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: el_main.c,v 1.16 2004/09/24 15:10:02 alor Exp $
 */
 
 #include <el.h>
@@ -29,6 +28,8 @@
 /* global options */
 struct globals gbls;
 
+void clean_exit(int errcode);
+
 
 /*******************************************/
 
@@ -92,7 +93,9 @@ int main(int argc, char *argv[])
    return 0;
 }
 
-
+void clean_exit(int errcode) {
+	exit(errcode);
+}
 
 /* ANSI color escapes */
 
